@@ -14,6 +14,9 @@
 #include "lib/string.h"
 #include "lib/resource.h"
 
+extern int shutting_down;
+extern int configuring;
+
 void
 cmd_show_status(void)
 {
@@ -27,9 +30,10 @@ cmd_show_status(void)
   cli_msg(-1011, "Last reboot on %s", tim);
   tm_format_datetime(tim, &config->tf_base, config->load_time);
   cli_msg(-1011, "Last reconfiguration on %s", tim);
+
   if (shutting_down)
     cli_msg(13, "Shutdown in progress");
-  else if (old_config)
+  else if (configuring)
     cli_msg(13, "Reconfiguration in progress");
   else
     cli_msg(13, "Daemon is up and running");
