@@ -121,7 +121,7 @@ static list near_timers, far_timers;
 static bird_clock_t first_far_timer = TIME_INFINITY;
 
 /* now must be different from 0, because 0 is a special value in timer->expires */
-bird_clock_t now = 1, now_real;
+bird_clock_t now = 1, now_real, boot_time;
 
 static void
 update_times_plain(void)
@@ -588,9 +588,12 @@ static struct resclass sk_class = {
  * This function creates a new socket resource. If you want to use it,
  * you need to fill in all the required fields of the structure and
  * call sk_open() to do the actual opening of the socket.
+ *
+ * The real function name is sock_new(), sk_new() is a macro wrapper
+ * to avoid collision with OpenSSL.
  */
 sock *
-sk_new(pool *p)
+sock_new(pool *p)
 {
   sock *s = ralloc(p, &sk_class);
   s->pool = p;
@@ -950,7 +953,7 @@ int
 sk_join_group(sock *s, ip_addr maddr)
 {
   struct ipv6_mreq mreq;
-	
+
   set_inaddr(&mreq.ipv6mr_multiaddr, maddr);
 
 #ifdef CONFIG_IPV6_GLIBC_20
@@ -1527,6 +1530,7 @@ io_init(void)
   krt_io_init();
   init_times();
   update_times();
+  boot_time = now;
   srandom((int) now_real);
 }
 
@@ -1554,7 +1558,7 @@ io_loop(void)
 	  tm_shot();
 	  continue;
 	}
-      timo.tv_sec = events ? 0 : tout - now;
+      timo.tv_sec = events ? 0 : MIN(tout - now, 3);
       timo.tv_usec = 0;
 
       if (sock_recalc_fdsets_p)
